*----------------------------------------------------------------------------
*
* PrintEase copyright (c) 1991,1992 DataEnter, Michael Kocum
*
* PrintEase includes a runtime version of Class(y), which
* is published by Integrated Development Corporation.
*
*----------------------------------------------------------------------------
*
* Global definitions
*
#define PE_TYP_IBM9             1       && type definition for IBM Graphic printer with 9 pins
#define PE_TYP_IBM24            5       && type definition for IBM Graphic printer with 24 pins
#define PE_TYP_EPSON9          11       && type definition for EPSON printer with 9 pins
#define PE_TYP_EPSON24         15       && type definition for EPSON printer with 24 pins
#define PE_TYP_PCL3            33       && type definition for PCL3 printer (HP Deskjet)
#define PE_TYP_PCL3ENH         34       && type definition for enhanced PCL3 printer (HP Deskjet Plus)
#define PE_TYP_PCL4            35       && type definition for PCL4 printer (HP Laserjet II)
#define PE_TYP_PCL5            36       && type definition for PCL5 printer (HP Laserjet III)
#define PE_TYP_POSTSCRIPT      91       && type definition for a Postscript printer
*----------------------------------------------------------------------------
*
* Error definitions
*
*
* Class is not able to open device or file
*
* possible problems:
*
* number of file handles in DOS or Clipper are to low
* wrong filename
* no such device
* no rights in the current directory ( LAN )
*
#define PE_ERROR_CantOpenDevice 		 01
*--------------------------------------------------
*
* Class is not able to write to device or file
* ( no characters can be written )
*
* possible problems:
*
* disk full
*
#define PE_ERROR_CantWriteToDevice		 02
*----------------------------------------------------------------------------
*
* Warning definitions
*
*
* Class accesses an invalid device
*
* possible problems:
* ------------------
* usually the parameter is not Chartyp
*
* corrections in class
* --------------------
* LPT1 is now assumed
*
#define PE_WARNING_NotAValidDevice    01
*--------------------------------------------------
*
* Class is not able to write to device or file
* ( some characters cannot be written )
*
* possible problems:
* ------------------
* disk full
* printer to slow
*
* corrections in class
* --------------------
* retry next time
*
#define PE_WARNING_CantWriteToDevice  02
*--------------------------------------------------
*
* string to be printed is too long for current line
* one ore more characters are out of the printable area
*
* possible problems:
* ------------------
* string too long
*
* corrections in class
* --------------------
* if Truncate == .T.  the string will be truncated to the maximal length
* if Truncate == .F.  the string will be printed as is
*
#define PE_WARNING_ColPastPage		  11
*--------------------------------------------------
*
* current col is past last col
*
*
* possible problems:
* ------------------
* string to be printed does not fit between cols
*
* oObj:Col(5)					<- go to col 5
* oObj:Print(replicate("A",20)) <- print a string of len 20 ( now we are in col 25)
* oObj:Col(10)					<- this is the line that generates the warning
*                                  because we are currently in col 25
*
*
* corrections in class
* --------------------
* adding a NewLine
*
#define PE_WARNING_ColPastLastCol     12
*--------------------------------------------------
*
* barcode does not fit onto page
*
*
* possible problems:
* ------------------
* printing a barcode at end of page
*
* corrections in class
* --------------------
* barcode will be truncated to fit into page
*
#define PE_WARNING_BarCodePastPage    13
*--------------------------------------------------
*
* an unknown paper source was specified
* in message PaperSource()
*
*
* possible problems:
* ------------------
* not used a definition from PE.CH
*
*
* corrections in class
* --------------------
* none (not accepted)
*
#define PE_WARNING_NotAValidPaper	  21
*--------------------------------------------------
*
* an unknown linespacing was specified
* in message Linespacing()
*
*
* possible problems:
* ------------------
*
*
* corrections in class
* --------------------
* none (not accepted)
*
#define PE_WARNING_NotAValidLinespacing 22
*--------------------------------------------------
*
* the specific PrinterDefinitionFile
* cannot be found
*
* possible problems:
* ------------------
* there is no PDFfile
*
* the class first scans the specified directory (usualy the current),
* then the directory, the environmet variable "PE" points to
*
* corrections in class
* --------------------
* standard PDF is assumed
*
#define PE_WARNING_CantOpenPDF        61
*--------------------------------------------------
*
* An error occured in reading the PrinterDefinitionFile
*
* possible problems:
* ------------------
* disk error
*
* corrections in class
* --------------------
* standard PDF is assumed
*
#define PE_WARNING_CantReadPDF        62
*--------------------------------------------------
*
* The file you specified is not a valid PrinterDefinitionFile
*
* possible problems:
* ------------------
* wrong name
*
* corrections in class
* --------------------
* default definitions are used
*
#define PE_WARNING_NotAPDF            63
*--------------------------------------------------
*
* Info definitions
*
*
* info sent at start of job
*
#define PE_INFO_StartOfJob			  1
*
* info sent when a character is printed
*
* This info based on the variable "CallInfo".
* Normally "CallInfo" is 10 and the info is sent every 10. time characters
* are printed, but if you change "CallInfo" to 50, the info is sent
* every 50. time characters are printed, and printing speed is higher.
*
*
#define PE_INFO_Character             2
*
* info sent at start of page
*
#define PE_INFO_StartOfPage           3
*
* info sent at end of page
*
#define PE_INFO_EndOfPage             4
*
* info sent at end of job
*
#define PE_INFO_EndOfJob              5
*----------------------------------------------------------------------------
*
* PaperSource definitions
*
* Please note: Not all printers support all trays.
* HP Laserjet III supports upper and manual tray.
* HP Laserjet IIID supports upper, lower and manual tray.
* A wide range of printers do not support any kind of tray.
*
#define PE_PAPERSOURCE_UpperTray         1
#define PE_PAPERSOURCE_LowerTray         2
#define PE_PAPERSOURCE_ManualTray        3
#define PE_PAPERSOURCE_FrontTray         4
#define PE_PAPERSOURCE_MiddleTray        5
#define PE_PAPERSOURCE_BackTray          6
*----------------------------------------------------------------------------
*
* Driver Code definitions
*
#define PE_CODE_BeforeAChar             1   && code sent before a printable Char ( PS only )
#define PE_CODE_AfterAChar              2   && code sent after a printable Char ( PS only )
#define PE_CODE_LineFeed                3   && code for moving to left corner in next line
#define PE_CODE_BeforeAPage             4   && code sent before a page starts ( PS only )
#define PE_CODE_AfterAPage              5   && code for moving to left corner in next page
#define PE_CODE_BeforeAJob              6   && code to reset printer to defaults
#define PE_CODE_AfterAJob               7   && code sent to end a job ( PS only )
#define PE_CODE_BoldOn                  8   && code sent to enable bold printing
#define PE_CODE_BoldOff                 9   && code sent to disable bold printing
#define PE_CODE_NLQOn                  10   && code sent to enable NLQ printing
#define PE_CODE_NLQOff                 11   && code sent to disable NLQ printing
#define PE_CODE_UnderLOn               12   && code sent to enable underline
#define PE_CODE_UnderLOff              13   && code sent to disable underline
#define PE_CODE_CondensedOff           14   && code sent to enable 10 CPI font
#define PE_CODE_CondensedOn            15   && code sent to enable condensed font
*
#define PE_CODE_Portrait               16   && code sent to set orientation to portrait
#define PE_CODE_Landscape              17   && code sent to set orientation to landscape
*
#define PE_CODE_EightLinesPerInch      18   && code sent to set linespacing to 8 lines / inch
#define PE_CODE_SixLinesPerInch        19   && code sent to set linespacing to 6 lines / inch
*
#define PE_CODE_PaperUpperTray         20   && code sent to use upper tray
#define PE_CODE_PaperLowerTray         21   && code sent to use lower tray
#define PE_CODE_PaperManualTray        22   && code sent to use maual tray
#define PE_CODE_PaperFrontTray         23   && code sent to use front tray
#define PE_CODE_PaperMiddleTray        24   && code sent to use middle tray
#define PE_CODE_PaperBackTray          25   && code sent to use back tray
*
* Here starts a userdefined region.
* Save your own codes and send it with
* oObject:OutCode( oObject:GetCode( nValue ) )
* to the printer
*
#define PE_CODE_Userdefined01          30   &&
#define PE_CODE_Userdefined02          31   &&
#define PE_CODE_Userdefined03          32   &&
#define PE_CODE_Userdefined04          33   &&
#define PE_CODE_Userdefined05          34   &&
#define PE_CODE_Userdefined06          35   &&
#define PE_CODE_Userdefined07          36   &&
#define PE_CODE_Userdefined08          37   &&
#define PE_CODE_Userdefined09          38   &&
#define PE_CODE_Userdefined10          39   &&
*
*----------------------------------------------------------------------------
